@@ -241,7 +241,6 @@ sub __func_with_col {
     my $function_stmts = [];
     for my $qt_col ( @$chosen_cols ) {
         push @$function_stmts, $fsql->function_with_col( $func, $qt_col );
-        $sf->{d}{default_alias}{$function_stmts->[-1]} = $function_stmts->[-1];
     }
     return $function_stmts;
 }
@@ -280,7 +279,6 @@ sub __func_with_col_and_arg {
             $value = $readline;
             @tmp_history = ( uniq $value, @tmp_history );
             push @$function_stmts, $fsql->function_with_col_and_arg( $func, $qt_col, $value );
-            $sf->{d}{default_alias}{$function_stmts->[-1]} = $function_stmts->[-1];
             $i++;
             if ( $i > $#$chosen_cols ) {
                 my @tmp_info = $sf->__get_info_rows( $chosen_cols, $function_stmts );
@@ -338,7 +336,6 @@ sub __func_with_col_and_2args {
             my $arg1 = $form->[0][1];
             my $arg2 = $form->[1][1];
             push @$function_stmts, $fsql->function_with_col_and_2args( $func, $qt_col, $arg1, $arg2 );
-            $sf->{d}{default_alias}{$function_stmts->[-1]} = $function_stmts->[-1];
             $fields = $form;
             $i++;
             if ( $i > $#$chosen_cols ) {
@@ -378,7 +375,6 @@ sub __func_Concat {
     }
     my $function_stmts = [ $fsql->concatenate( $chosen_cols, $sep ) ];
     my $unquoted_chosen_cols = [ map { $ax->unquote_identifier( $_ ) } @$chosen_cols ];
-    $sf->{d}{default_alias}{$function_stmts->[-1]} = $function_stmts->[-1];
     return $function_stmts;
 }
 
@@ -481,7 +477,6 @@ sub __interval_to_converted_epoch { #
     else {
         $stmt_convert_epoch = $fsql->epoch_to_date( $qt_col, $interval );
     }
-    $sf->{d}{default_alias}{$stmt_convert_epoch} = $stmt_convert_epoch;
     my $stmt = $sf->__select_stmt( $sql, $stmt_convert_epoch, $qt_col );
     my $example_results = $sf->{d}{dbh}->selectcol_arrayref( $stmt, { Columns => [1], MaxRows => $maxrows }, @{$sql->{where_args}//[]} );
     return $stmt_convert_epoch, $example_results;
@@ -566,7 +561,6 @@ sub __choose_interval {
             );
             if ( ! $idx ) {
                 if ( $i == 0 ) {
-                    delete @{$sf->{d}{default_alias}}{@$function_stmts};
                     return;
                 }
                 else {
